@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: aws
 version: 0.13.0
-id: aws-0.13.0-0f46a4bdfae8fbffb3594613b97c34da
-key: aws_0FsmBkWKHye8HrFDysXNyc
+id: aws-0.13.0-51867863ade718d5b183521603405791
+key: aws_3WZz6qZwm494PnhTVJVSpq
 license: BSD3
 copyright: See contributors list in README and LICENSE file
 maintainer: aristidb@gmail.com
@@ -55,7 +55,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/aws-0.13.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/aws-0.13.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/aws-0.13.0
-hs-libraries: HSaws-0.13.0-0FsmBkWKHye8HrFDysXNyc
+hs-libraries: HSaws-0.13.0-3WZz6qZwm494PnhTVJVSpq
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
@@ -74,7 +74,7 @@ depends:
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    http-conduit-2.1.8-52d716dea2bf146bfe94bcf5c020ce6a
+    http-conduit-2.1.9-a114e1e30c63561e9380f63d9f83e5a8
     http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
     lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
     monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
